@@ -26,21 +26,20 @@ __copyright__ = """
 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-__version__ = "2.0.1"
-
+__version__ = "2.0.3"
 repo_root = pathlib.Path(__file__).parent
 install_requires = (repo_root / "requirements.txt").read_text(encoding="utf-8").split('\n')
 extras_require = {
 		"testing": [
+				"domdf-python-tools[testing]>=1.5.0",
 				"pygments>=2.7.4",
 				"pytest>=6.0.0",
-				"pytest-regressions>=2.0.2",
-				"domdf-python-tools[testing]>=1.5.0"
+				"pytest-regressions>=2.0.3"
 				],
 		"all": [
 				"domdf-python-tools[testing]>=1.5.0",
 				"pygments>=2.7.4",
-				"pytest-regressions>=2.0.2",
-				"pytest>=6.0.0"
+				"pytest>=6.0.0",
+				"pytest-regressions>=2.0.3"
 				]
 		}
